package com.codepoka.number_hint.number_hint

import android.app.Activity
import android.content.Intent
import android.content.IntentSender.SendIntentException
import com.google.android.gms.auth.api.Auth
import com.google.android.gms.auth.api.credentials.Credential
import com.google.android.gms.auth.api.credentials.HintRequest
import com.google.android.gms.common.api.GoogleApiClient
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.lang.Exception


class NumberHintPlugin(private val channel: MethodChannel,private  val registrar: Registrar) : MethodCallHandler {
    private val PHONE_HINT_REQUEST = 11012

    init {
        registrar.addActivityResultListener(object : PluginRegistry.ActivityResultListener{
            override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {
                if (requestCode == PHONE_HINT_REQUEST) {
                    try {
                        if (resultCode == Activity.RESULT_OK) {
                            if(data != null && data!!.extras[Credential.EXTRA_KEY] != null){
                                val number = (data.extras[Credential.EXTRA_KEY] as Credential).id
                                channel.invokeMethod("hint_number",number)
                            }else{
                                channel.invokeMethod("hint_number",null)
                            }
                        }
                        else if(resultCode == 1001)
                        {
                            channel.invokeMethod("hint_number","NONE_OF_THE_ABOVE")
                        }else{
                            channel.invokeMethod("hint_number",null)
                        }
                    }catch (e:Exception){
                        e.printStackTrace()
                        channel.invokeMethod("hint_number","")
                    }
                    return true
                }
                return false
            }
        })
    }


  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "number_hint")
      channel.setMethodCallHandler(NumberHintPlugin(channel, registrar))
    }
  }

  override fun onMethodCall(call: MethodCall, result: Result) {
    if (call.method == "getNumberHint") {
        requestHint()
        result.success("")
    } else {
      result.notImplemented()
    }
  }

    private fun requestHint() {
        val hintRequest = HintRequest.Builder()
                .setPhoneNumberIdentifierSupported(true)
                .build()
        val mCredentialsClient = GoogleApiClient.Builder(registrar.activity())
                .addApi(Auth.CREDENTIALS_API)
                .build()
        val intent = Auth.CredentialsApi.getHintPickerIntent(
                mCredentialsClient, hintRequest)
        try {
            registrar.activity().startIntentSenderForResult(intent.intentSender,
                    PHONE_HINT_REQUEST, null, 0, 0, 0)
        } catch (e: SendIntentException) {
            e.printStackTrace()
        }
    }
}
